#
# Fedora spec file for php-Assetic
#
# Copyright (c) 2013-2016 Shawn Iwinski <shawn.iwinski@gmail.com>
#
# License: MIT
# http://opensource.org/licenses/MIT
#
# Please preserve changelog entries
#

%global github_owner     kriswallsmith
%global github_name      assetic
%global github_version   1.2.1
%global github_commit    b20efe38845d20458702f97f3ff625d80805897b

%global composer_vendor  kriswallsmith
%global composer_project assetic

# "php": ">=5.3.1"
%global php_min_ver 5.3.1
# "psr/log": "~1.0"
#     NOTE: Min version not 1.0 because autoloader required
%global psr_log_min_ver 1.0.0-8
%global psr_log_max_ver 2.0
# "leafo/scssphp": "*"
#     NOTE: Min version added because autoloader required
%global scssphp_min_ver 0.1.6
# "symfony/process": "~2.1"
#     NOTE: Min version not 2.1 because autoloader required
%global symfony_min_ver %{?el6:2.3.31}%{!?el6:2.7.1}
%global symfony_max_ver 3.0
# "twig/twig": "~1.6"
#     NOTE: Min version not 1.6 because autoloader required
%global twig_min_ver 1.18.2
%global twig_max_ver 3.0

# Build using "--without tests" to disable tests
%global with_tests 0%{!?_without_tests:1}

%{!?phpdir:  %global phpdir  %{_datadir}/php}

Name:          php-Assetic
Version:       %{github_version}
Release:       4%{?dist}
Summary:       Asset Management for PHP

Group:         Development/Libraries
License:       MIT
URL:           https://github.com/%{github_owner}/%{github_name}

# GitHub export does not include tests.
# Run php-Assetic-get-source.sh to create full source.
Source0:       %{name}-%{github_version}-%{github_commit}.tar.gz
Source1:       %{name}-get-source.sh

BuildArch:     noarch
# Tests
%if %{with_tests}
## composer.json
BuildRequires: php(language)                 >= %{php_min_ver}
BuildRequires: php-composer(leafo/lessphp)
BuildRequires: php-composer(leafo/scssphp)   >= %{scssphp_min_ver}
BuildRequires: php-composer(phpunit/phpunit)
#BuildRequires: php-composer(psr/log)         >= %%{psr_log_min_ver}
BuildRequires: php-PsrLog                    >= %{psr_log_min_ver}
BuildRequires: php-composer(symfony/process) >= %{symfony_min_ver}
BuildRequires: php-composer(twig/twig)       >= %{twig_min_ver}
## phpcompatinfo (computed from version 1.2.1)
BuildRequires: php-ctype
BuildRequires: php-curl
BuildRequires: php-date
BuildRequires: php-fileinfo
BuildRequires: php-hash
BuildRequires: php-json
BuildRequires: php-pcre
BuildRequires: php-simplexml
BuildRequires: php-spl
BuildRequires: php-tokenizer
## Autoloader
BuildRequires: php-composer(symfony/class-loader)
%endif

# composer.json
Requires:      php(language)                 >= %{php_min_ver}
Requires:      php-composer(symfony/process) >= %{symfony_min_ver}
Requires:      php-composer(symfony/process) <  %{symfony_max_ver}
# phpcompatinfo (computed from version 1.2.1)
Requires:      php-ctype
Requires:      php-curl
Requires:      php-date
Requires:      php-hash
Requires:      php-json
Requires:      php-pcre
Requires:      php-spl
Requires:      php-tokenizer
# Autoloader
Requires:      php-composer(symfony/class-loader)

# Weak dependencies
%if 0%{?fedora} >= 21
Suggests:      php-composer(leafo/lessphp)
Suggests:      php-composer(leafo/scssphp)
Suggests:      php-composer(twig/twig)
Suggests:      php-pecl(apcu)
%endif
Conflicts:     php-composer(leafo/scssphp) <  %{scssphp_min_ver}
Conflicts:     php-composer(twig/twig)     <  %{twig_min_ver}
Conflicts:     php-composer(twig/twig)     >= %{twig_max_ver}

# Standard "php-{COMPOSER_VENDOR}-{COMPOSER_PROJECT}" naming
Provides:      php-%{composer_vendor}-%{composer_project}             = %{version}-%{release}
# Composer
Provides:      php-composer(%{composer_vendor}/%{composer_project})   = %{version}

%description
Assetic is an asset management framework for PHP.

Autoloader: %{phpdir}/Assetic/autoload.php

Optional packages:
* https://github.com/leafo/scssphp-compass
* https://github.com/krichprollsch/phpCssEmbed


%prep
%setup -q -n %{github_name}-%{github_commit}

: Move functions file
mv src/functions.php src/Assetic/


%build
: Create autoloader
cat <<'AUTOLOAD' | tee src/Assetic/autoload.php
<?php
/**
 * Autoloader for %{name} and its' dependencies
 * (created by %{name}-%{version}-%{release}).
 *
 * @return \Symfony\Component\ClassLoader\ClassLoader
 */

if (!isset($fedoraClassLoader) || !($fedoraClassLoader instanceof \Symfony\Component\ClassLoader\ClassLoader)) {
    if (!class_exists('Symfony\\Component\\ClassLoader\\ClassLoader', false)) {
        require_once '%{phpdir}/Symfony/Component/ClassLoader/ClassLoader.php';
    }

    $fedoraClassLoader = new \Symfony\Component\ClassLoader\ClassLoader();
    $fedoraClassLoader->register();
}

$fedoraClassLoader->addPrefix('Assetic\\', dirname(__DIR__));
require_once __DIR__.'/functions.php';

// Required dependencies
require_once '%{phpdir}/Symfony/Component/Process/autoload.php';

// Optional dependencies
@include_once '%{phpdir}/Leafo/ScssPhp/autoload.php';
@include_once '%{phpdir}/lessphp/lessc.inc.php';
@include_once '%{phpdir}/Twig/autoload.php';

return $fedoraClassLoader;
AUTOLOAD


%install
mkdir -p %{buildroot}%{phpdir}
cp -rp src/Assetic %{buildroot}%{phpdir}/


%check
%if %{with_tests}
: Skip tests known to fail
rm -f \
    tests/Assetic/Test/Asset/HttpAssetTest.php \
    tests/Assetic/Test/Filter/GoogleClosure/CompilerApiFilterTest.php
sed -e 's/function testSass/function SKIP_testSass/' \
    -e 's/function testScssGuess/function SKIP_testScssGuess/' \
    -i tests/Assetic/Test/Filter/Sass/SassFilterTest.php

: Create tests bootstrap
cat <<'BOOTSTRAP' | tee bootstrap.php
<?php
$fedoraClassLoader = require '%{buildroot}%{phpdir}/Assetic/autoload.php';
$fedoraClassLoader->addPrefix('Assetic\\Test\\', __DIR__.'/tests');
BOOTSTRAP

: Run tests
%{_bindir}/phpunit --verbose --bootstrap bootstrap.php
%else
: Tests skipped
%endif


%files
%{!?_licensedir:%global license %%doc}
%license LICENSE
%doc *.json
%doc *.md
%doc docs
%{phpdir}/Assetic


%changelog
* Fri Mar 25 2016 Shawn Iwinski <shawn.iwinski@gmail.com> - 1.2.1-4
- Added spec copyright header
- Included tests in source, added BuildRequires, enabled tests
- Dependencies changed to virtual provides ("php*(*)")
- Added weak dependencies suggests (Fedora >= 21)
- Added autoloader
- Added additional docs

* Thu Feb 04 2016 Fedora Release Engineering <releng@fedoraproject.org> - 1.2.1-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Thu Jun 18 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.2.1-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Mon Dec 29 2014 Adam Williamson <awilliam@redhat.com> - 1.2.1-1
- new release 1.2.1

* Sat Jun 07 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.1.2-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Sun Aug 18 2013 Shawn Iwinski <shawn.iwinski@gmail.com> - 1.1.2-1
- Updated to 1.1.2

* Sun Aug 04 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.1.1-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Fri Jun 07 2013 Shawn Iwinski <shawn.iwinski@gmail.com> - 1.1.1-1
- Updated to 1.1.1

* Sat Mar 09 2013 Shawn Iwinski <shawn.iwinski@gmail.com> - 1.1.0-0.2.alpha4
- Updated to upstream pre-release version 1.1.0-alpha4

* Wed Feb 27 2013 Shawn Iwinski <shawn.iwinski@gmail.com> - 1.1.0-0.1.alpha3
- Initial package
